@@ -23,8 +23,11 @@ SUPPORTED_LANGS = {
     "en",
     "de",
     "es",
+    "ja",
+    "ko",
     "pt",
     "ru",
+    "uk",
 }
 
 
@@ -128,14 +131,9 @@ def new_lang(lang: str = typer.Argument(..., callback=lang_callback)):
     new_path.mkdir()
     new_config_path: Path = Path(new_path) / mkdocs_name
     new_config_path.write_text("INHERIT: ../en/mkdocs.yml\n", encoding="utf-8")
-    new_config_docs_path: Path = new_path / "docs"
-    new_config_docs_path.mkdir()
-    en_index_path: Path = en_docs_path / "docs" / "index.md"
-    new_index_path: Path = new_config_docs_path / "index.md"
-    en_index_content = en_index_path.read_text(encoding="utf-8")
-    new_index_content = f"{missing_translation_snippet}\n\n{en_index_content}"
-    new_index_path.write_text(new_index_content, encoding="utf-8")
-    typer.secho(f"Successfully initialized: {new_path}", color=typer.colors.GREEN)
+    new_llm_prompt_path: Path = new_path / "llm-prompt.md"
+    new_llm_prompt_path.write_text("", encoding="utf-8")
+    print(f"Successfully initialized: {new_path}")
     update_languages()
 
 
@@ -239,7 +237,7 @@ def generate_readme() -> None:
     Generate README.md content from main index.md
     """
     readme_path = Path("README.md")
-    old_content = readme_path.read_text()
+    old_content = readme_path.read_text("utf-8")
     new_content = generate_readme_content()
     if new_content != old_content:
         print("README.md outdated from the latest index.md")
