@@ -1,5 +1,4 @@
 import pytest
-from dirty_equals import IsDict
 from fastapi.testclient import TestClient
 
 from .main import app
@@ -274,14 +273,10 @@ def test_openapi_schema():
                             "name": "item_id",
                             "in": "path",
                             "required": True,
-                            "schema": IsDict(
-                                {
-                                    "anyOf": [{"type": "string"}, {"type": "null"}],
-                                    "title": "Item Id",
-                                }
-                            )
-                            # TODO: remove when deprecating Pydantic v1
-                            | IsDict({"title": "Item Id", "type": "string"}),
+                            "schema": {
+                                "anyOf": [{"type": "string"}, {"type": "null"}],
+                                "title": "Item Id",
+                            },
                         }
                     ],
                 }
@@ -984,14 +979,10 @@ def test_openapi_schema():
                             "name": "query",
                             "in": "query",
                             "required": False,
-                            "schema": IsDict(
-                                {
-                                    "anyOf": [{"type": "integer"}, {"type": "null"}],
-                                    "title": "Query",
-                                }
-                            )
-                            # TODO: remove when deprecating Pydantic v1
-                            | IsDict({"title": "Query", "type": "integer"}),
+                            "schema": {
+                                "anyOf": [{"type": "integer"}, {"type": "null"}],
+                                "title": "Query",
+                            },
                         }
                     ],
                 }
@@ -1269,6 +1260,8 @@ def test_openapi_schema():
                         },
                         "msg": {"title": "Message", "type": "string"},
                         "type": {"title": "Error Type", "type": "string"},
+                        "input": {"title": "Input"},
+                        "ctx": {"title": "Context", "type": "object"},
                     },
                 },
                 "HTTPValidationError": {
