@@ -1,8 +1,9 @@
 from decimal import Decimal
 
-from dirty_equals import IsDict, IsOneOf
+from dirty_equals import IsOneOf
 from fastapi import FastAPI
 from fastapi.testclient import TestClient
+from inline_snapshot import snapshot
 from pydantic import BaseModel, condecimal
 
 app = FastAPI()
@@ -24,109 +25,65 @@ client = TestClient(app)
 def test_put_correct_body():
     response = client.post("/items/", json=[{"name": "Foo", "age": 5}])
     assert response.status_code == 200, response.text
-    assert response.json() == {
-        "item": [
-            {
-                "name": "Foo",
-                "age": IsOneOf(
-                    5,
-                    # TODO: remove when deprecating Pydantic v1
-                    "5",
-                ),
-            }
-        ]
-    }
+    assert response.json() == snapshot(
+        {
+            "item": [
+                {
+                    "name": "Foo",
+                    "age": "5",
+                }
+            ]
+        }
+    )
 
 
 def test_jsonable_encoder_requiring_error():
     response = client.post("/items/", json=[{"name": "Foo", "age": -1.0}])
     assert response.status_code == 422, response.text
-    assert response.json() == IsDict(
-        {
-            "detail": [
-                {
-                    "type": "greater_than",
-                    "loc": ["body", 0, "age"],
-                    "msg": "Input should be greater than 0",
-                    "input": -1.0,
-                    "ctx": {"gt": 0},
-                }
-            ]
-        }
-    ) | IsDict(
-        # TODO: remove when deprecating Pydantic v1
-        {
-            "detail": [
-                {
-                    "ctx": {"limit_value": 0.0},
-                    "loc": ["body", 0, "age"],
-                    "msg": "ensure this value is greater than 0",
-                    "type": "value_error.number.not_gt",
-                }
-            ]
-        }
-    )
+    assert response.json() == {
+        "detail": [
+            {
+                "type": "greater_than",
+                "loc": ["body", 0, "age"],
+                "msg": "Input should be greater than 0",
+                "input": -1.0,
+                "ctx": {"gt": 0},
+            }
+        ]
+    }
 
 
 def test_put_incorrect_body_multiple():
     response = client.post("/items/", json=[{"age": "five"}, {"age": "six"}])
     assert response.status_code == 422, response.text
-    assert response.json() == IsDict(
-        {
-            "detail": [
-                {
-                    "type": "missing",
-                    "loc": ["body", 0, "name"],
-                    "msg": "Field required",
-                    "input": {"age": "five"},
-                },
-                {
-                    "type": "decimal_parsing",
-                    "loc": ["body", 0, "age"],
-                    "msg": "Input should be a valid decimal",
-                    "input": "five",
-                },
-                {
-                    "type": "missing",
-                    "loc": ["body", 1, "name"],
-                    "msg": "Field required",
-                    "input": {"age": "six"},
-                },
-                {
-                    "type": "decimal_parsing",
-                    "loc": ["body", 1, "age"],
-                    "msg": "Input should be a valid decimal",
-                    "input": "six",
-                },
-            ]
-        }
-    ) | IsDict(
-        # TODO: remove when deprecating Pydantic v1
-        {
-            "detail": [
-                {
-                    "loc": ["body", 0, "name"],
-                    "msg": "field required",
-                    "type": "value_error.missing",
-                },
-                {
-                    "loc": ["body", 0, "age"],
-                    "msg": "value is not a valid decimal",
-                    "type": "type_error.decimal",
-                },
-                {
-                    "loc": ["body", 1, "name"],
-                    "msg": "field required",
-                    "type": "value_error.missing",
-                },
-                {
-                    "loc": ["body", 1, "age"],
-                    "msg": "value is not a valid decimal",
-                    "type": "type_error.decimal",
-                },
-            ]
-        }
-    )
+    assert response.json() == {
+        "detail": [
+            {
+                "type": "missing",
+                "loc": ["body", 0, "name"],
+                "msg": "Field required",
+                "input": {"age": "five"},
+            },
+            {
+                "type": "decimal_parsing",
+                "loc": ["body", 0, "age"],
+                "msg": "Input should be a valid decimal",
+                "input": "five",
+            },
+            {
+                "type": "missing",
+                "loc": ["body", 1, "name"],
+                "msg": "Field required",
+                "input": {"age": "six"},
+            },
+            {
+                "type": "decimal_parsing",
+                "loc": ["body", 1, "age"],
+                "msg": "Input should be a valid decimal",
+                "input": "six",
+            },
+        ]
+    }
 
 
 def test_openapi_schema():
@@ -179,31 +136,21 @@ def test_openapi_schema():
                     "type": "object",
                     "properties": {
                         "name": {"title": "Name", "type": "string"},
-                        "age": IsDict(
-                            {
-                                "title": "Age",
-                                "anyOf": [
-                                    {"exclusiveMinimum": 0.0, "type": "number"},
-                                    IsOneOf(
-                                        # pydantic < 2.12.0
-                                        {"type": "string"},
-                                        # pydantic >= 2.12.0
-                                        {
-                                            "type": "string",
-                                            "pattern": r"^(?!^[-+.]*$)[+-]?0*\d*\.?\d*$",
-                                        },
-                                    ),
-                                ],
-                            }
-                        )
-                        | IsDict(
-                            # TODO: remove when deprecating Pydantic v1
-                            {
-                                "title": "Age",
-                                "exclusiveMinimum": 0.0,
-                                "type": "number",
-                            }
-                        ),
+                        "age": {
+                            "title": "Age",
+                            "anyOf": [
+                                {"exclusiveMinimum": 0.0, "type": "number"},
+                                IsOneOf(
+                                    # pydantic < 2.12.0
+                                    {"type": "string"},
+                                    # pydantic >= 2.12.0
+                                    {
+                                        "type": "string",
+                                        "pattern": r"^(?!^[-+.]*$)[+-]?0*\d*\.?\d*$",
+                                    },
+                                ),
+                            ],
+                        },
                     },
                 },
                 "ValidationError": {
@@ -220,6 +167,8 @@ def test_openapi_schema():
                         },
                         "msg": {"title": "Message", "type": "string"},
                         "type": {"title": "Error Type", "type": "string"},
+                        "input": {"title": "Input"},
+                        "ctx": {"title": "Context", "type": "object"},
                     },
                 },
                 "HTTPValidationError": {
