@@ -2,7 +2,7 @@ from __future__ import annotations
 
 import uuid
 from dataclasses import dataclass, field
-from typing import List, Union
+from typing import Union
 
 from dirty_equals import IsUUID
 from fastapi import FastAPI
@@ -15,7 +15,7 @@ class Item:
     id: uuid.UUID
     name: str
     price: float
-    tags: List[str] = field(default_factory=list)
+    tags: list[str] = field(default_factory=list)
     description: Union[str, None] = None
     tax: Union[float, None] = None
 
