@@ -1,8 +1,9 @@
 from __future__ import annotations
 
+from typing import Annotated
+
 from fastapi import Depends, FastAPI, Request
 from fastapi.testclient import TestClient
-from typing_extensions import Annotated
 
 from .utils import needs_py310
 
