@@ -121,6 +121,8 @@ def test_openapi_schema(client: TestClient) -> None:
                 },
                 "ValidationError": {
                     "properties": {
+                        "ctx": {"title": "Context", "type": "object"},
+                        "input": {"title": "Input"},
                         "loc": {
                             "items": {
                                 "anyOf": [{"type": "string"}, {"type": "integer"}]
